@@ -235,6 +235,8 @@ paste.vec <- function(name, digits = options()$digits)
 }
 signi <- function(x, digits = 6) round(x, digits - trunc(log10(abs(x))))
 
+##' NB:  Since ~ R 3.3.0 (May 2016),  use base R's "new"   strrep(x, times)  instead
+
 repChar <- function(char, no) paste(rep.int(char, no), collapse = "")
 ## correct, but slower than the next one:
 bl.string <- function(no) repChar(" ", no)
@@ -788,7 +790,7 @@ diagX <- function(n)
   ## Arguments: n: integer dimension of matrix
   ## ----------------------------------------------------------------
     m <- numeric(n * n)
-    m[1+ (n-1)* (1:n)] <- 1
+    m[1L+ (n-1L)* seq_len(n)] <- 1
     dim(m) <- c(n,n)
     m
 }
